svn commit: r1152117 - /subversion/trunk/subversion/tests/cmdline/copy_tests.py

2011-07-28 Thread danielsh
Author: danielsh
Date: Fri Jul 29 06:26:08 2011
New Revision: 1152117

URL: http://svn.apache.org/viewvc?rev=1152117&view=rev
Log:
* subversion/tests/cmdline/copy_tests.py
  (commit_copied_half_of_move, commit_deleted_half_of_move):
Don't create a repository for these tests.

Modified:
subversion/trunk/subversion/tests/cmdline/copy_tests.py

Modified: subversion/trunk/subversion/tests/cmdline/copy_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/copy_tests.py?rev=1152117&r1=1152116&r2=1152117&view=diff
==
--- subversion/trunk/subversion/tests/cmdline/copy_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/copy_tests.py Fri Jul 29 06:26:08 
2011
@@ -5444,7 +5444,7 @@ def copy_and_move_conflicts(sbox):
 
 def commit_copied_half_of_move(sbox):
   "attempt to commit the copied part of move"
-  sbox.build()
+  sbox.build(read_only = True)
   wc_dir = sbox.wc_dir
 
   iota_path = os.path.join(wc_dir, 'iota')
@@ -5460,7 +5460,7 @@ def commit_copied_half_of_move(sbox):
 @XFail()
 def commit_deleted_half_of_move(sbox):
   "attempt to commit the deleted part of move"
-  sbox.build()
+  sbox.build(read_only = True)
   wc_dir = sbox.wc_dir
 
   iota_path = os.path.join(wc_dir, 'iota')




Re: svn commit: r1152026 - /subversion/trunk/subversion/libsvn_client/commit.c

2011-07-28 Thread Hyrum K Wright
On Thu, Jul 28, 2011 at 3:35 PM,   wrote:
> Author: stsp
> Date: Thu Jul 28 22:35:57 2011
> New Revision: 1152026
>
> URL: http://svn.apache.org/viewvc?rev=1152026&view=rev
> Log:
> Make commit refuse to commit the copied-half of a move independently of
> the delete-half.
>
> It is still possible to commit the delete-half independently of the
> copied-half. That will be fixed soon.
>
> This is the first visible behaviour change for moves.
> None of our existing tests trigger the new error condition so writing
> new tests wouldn't be a bad idea. I'll add some if nobody beats me to it.

See r1152115.

-Hyrum

>
> * subversion/libsvn_client/commit.c
>  (svn_client_commit5): Raise an error if the delete-half corresponding
>   to the copied-half of a moved commit target does not appear in the
>   commit target list.
>
> Modified:
>    subversion/trunk/subversion/libsvn_client/commit.c
>
> Modified: subversion/trunk/subversion/libsvn_client/commit.c
> URL: 
> http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/commit.c?rev=1152026&r1=1152025&r2=1152026&view=diff
> ==
> --- subversion/trunk/subversion/libsvn_client/commit.c (original)
> +++ subversion/trunk/subversion/libsvn_client/commit.c Thu Jul 28 22:35:57 
> 2011
> @@ -1356,6 +1356,47 @@ svn_client_commit5(const apr_array_heade
>       goto cleanup;
>   }
>
> +  /* For every target that was moved verify that both halves of the
> +   * move are part of the commit. */
> +  for (i = 0; i < commit_items->nelts; i++)
> +    {
> +      svn_client_commit_item3_t *item =
> +        APR_ARRAY_IDX(commit_items, i, svn_client_commit_item3_t *);
> +
> +      svn_pool_clear(iterpool);
> +
> +      if (item->state_flags & SVN_CLIENT_COMMIT_ITEM_IS_COPY)
> +        {
> +          const char *moved_from_abspath;
> +          const char *delete_op_root_abspath;
> +
> +          cmt_err = svn_error_trace(svn_wc__node_was_moved_here(
> +                                      &moved_from_abspath,
> +                                      &delete_op_root_abspath,
> +                                      ctx->wc_ctx, item->path,
> +                                      iterpool, iterpool));
> +          if (cmt_err)
> +            goto cleanup;
> +
> +          if (moved_from_abspath && delete_op_root_abspath &&
> +              strcmp(moved_from_abspath, delete_op_root_abspath) == 0 &&
> +              apr_hash_get(committables->by_path, delete_op_root_abspath,
> +                           APR_HASH_KEY_STRING) == NULL)
> +            {
> +              cmt_err = svn_error_createf(
> +                          SVN_ERR_ILLEGAL_TARGET, NULL,
> +                          _("Cannot commit '%s' because it was moved from "
> +                            "'%s' which is not part of the commit; both "
> +                            "sides of the move must be committed together"),
> +                          svn_dirent_local_style(item->path, iterpool),
> +                          svn_dirent_local_style(delete_op_root_abspath,
> +                                                 iterpool));
> +              goto cleanup;
> +            }
> +        }
> +      /* ### TODO: check the delete-half, too */
> +    }
> +
>   /* Go get a log message.  If an error occurs, or no log message is
>      specified, abort the operation. */
>   if (SVN_CLIENT__HAS_LOG_MSG_FUNC(ctx))
>
>
>



-- 

uberSVN: Apache Subversion Made Easy
http://www.uberSVN.com/


svn commit: r1152115 - /subversion/trunk/subversion/tests/cmdline/copy_tests.py

2011-07-28 Thread hwright
Author: hwright
Date: Fri Jul 29 06:05:52 2011
New Revision: 1152115

URL: http://svn.apache.org/viewvc?rev=1152115&view=rev
Log:
Add a couple of tests in followup to r1152026.

(There's probably an issue this is associated with, but I'm not sure which one
it is.  If you know, please update the tests and this log message!)

* subversion/tests/cmdline/copy_tests.py
  (commit_copied_half_of_move, commit_deleted_half_of_move): New.
  (test_list): Run the new tests.

Modified:
subversion/trunk/subversion/tests/cmdline/copy_tests.py

Modified: subversion/trunk/subversion/tests/cmdline/copy_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/copy_tests.py?rev=1152115&r1=1152114&r2=1152115&view=diff
==
--- subversion/trunk/subversion/tests/cmdline/copy_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/copy_tests.py Fri Jul 29 06:05:52 
2011
@@ -5442,6 +5442,36 @@ def copy_and_move_conflicts(sbox):
   svntest.actions.verify_disk(wc('move-dest'), expected_disk, True)
 
 
+def commit_copied_half_of_move(sbox):
+  "attempt to commit the copied part of move"
+  sbox.build()
+  wc_dir = sbox.wc_dir
+
+  iota_path = os.path.join(wc_dir, 'iota')
+  D_path = os.path.join(wc_dir, 'A', 'D')
+
+  svntest.actions.run_and_verify_svn(None, None, [], 'mv', iota_path, D_path)
+
+  expected_error = "svn: E29: Cannot commit"
+  svntest.actions.run_and_verify_svn(None, None, expected_error,
+ 'commit', '-m', 'foo', D_path)
+
+
+@XFail()
+def commit_deleted_half_of_move(sbox):
+  "attempt to commit the deleted part of move"
+  sbox.build()
+  wc_dir = sbox.wc_dir
+
+  iota_path = os.path.join(wc_dir, 'iota')
+  D_path = os.path.join(wc_dir, 'A', 'D')
+
+  svntest.actions.run_and_verify_svn(None, None, [], 'mv', iota_path, D_path)
+
+  expected_error = "svn: E29: Cannot commit"
+  svntest.actions.run_and_verify_svn(None, None, expected_error,
+ 'commit', '-m', 'foo', iota_path)
+
 
 # Run the tests
 
@@ -5551,6 +5581,8 @@ test_list = [ None,
   copy_base_of_deleted,
   case_only_rename,
   copy_and_move_conflicts,
+  commit_copied_half_of_move,
+  commit_deleted_half_of_move,
  ]
 
 if __name__ == '__main__':




svn commit: r1152054 - /subversion/branches/revprop-packing/BRANCH-README

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 23:58:52 2011
New Revision: 1152054

URL: http://svn.apache.org/viewvc?rev=1152054&view=rev
Log:
On the revprop-packing branch, remove a task from BRANCH-README.

Modified:
subversion/branches/revprop-packing/BRANCH-README

Modified: subversion/branches/revprop-packing/BRANCH-README
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/BRANCH-README?rev=1152054&r1=1152053&r2=1152054&view=diff
==
--- subversion/branches/revprop-packing/BRANCH-README (original)
+++ subversion/branches/revprop-packing/BRANCH-README Thu Jul 28 23:58:52 2011
@@ -27,8 +27,6 @@ TODO:
 * add some explicit tests for svnadmin upgrade/pack
   (both revs and revrops)
 
-* assertion failure in svnadmin_tests 13 with pre-1.8-compatible
-
 
 Suggested:
 




svn commit: r1152053 - /subversion/branches/revprop-packing/subversion/libsvn_fs_fs/fs_fs.c

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 23:57:50 2011
New Revision: 1152053

URL: http://svn.apache.org/viewvc?rev=1152053&view=rev
Log:
On the revprop-packing branch, fix an assertion.

* subversion/libsvn_fs_fs/fs_fs.c
  (recover_body): Guard a call by the appropriate format number check.

Modified:
subversion/branches/revprop-packing/subversion/libsvn_fs_fs/fs_fs.c

Modified: subversion/branches/revprop-packing/subversion/libsvn_fs_fs/fs_fs.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/subversion/libsvn_fs_fs/fs_fs.c?rev=1152053&r1=1152052&r2=1152053&view=diff
==
--- subversion/branches/revprop-packing/subversion/libsvn_fs_fs/fs_fs.c 
(original)
+++ subversion/branches/revprop-packing/subversion/libsvn_fs_fs/fs_fs.c Thu Jul 
28 23:57:50 2011
@@ -7329,7 +7329,8 @@ recover_body(void *baton, apr_pool_t *po
 
   /* Before setting current, verify that there is a revprops file
  for the youngest revision.  (Issue #2992) */
-  SVN_ERR(update_min_unpacked_revprop(fs, pool));
+  if (ffd->format >= SVN_FS_FS__MIN_PACKED_REVPROP_FORMAT)
+SVN_ERR(update_min_unpacked_revprop(fs, pool));
   if (is_packed_revprop(fs, max_rev))
 /* Possible when min_unpacked_rev == current+1 == max_rev+1. */
 SVN_ERR(svn_io_check_path(path_revprops_pack(fs, max_rev, pool),




svn commit: r1152035 - /subversion/trunk/subversion/libsvn_wc/wc_db.c

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 23:13:53 2011
New Revision: 1152035

URL: http://svn.apache.org/viewvc?rev=1152035&view=rev
Log:
* subversion/libsvn_wc/wc_db.c
  (scan_addition_txn): Always initialise the MOVED_FROM_RELPATH and
   DELETE_OP_ROOT_RELPATH output parameters. Should fix failing tests
   on the windows buildbot.

Modified:
subversion/trunk/subversion/libsvn_wc/wc_db.c

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.c?rev=1152035&r1=1152034&r2=1152035&view=diff
==
--- subversion/trunk/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.c Thu Jul 28 23:13:53 2011
@@ -9127,6 +9127,10 @@ scan_addition_txn(void *baton,
 *sab->original_repos_id = INVALID_REPOS_ID;
   if (sab->original_revision)
 *sab->original_revision = SVN_INVALID_REVNUM;
+  if (sab->moved_from_relpath)
+*sab->moved_from_relpath = NULL;
+  if (sab->delete_op_root_relpath)
+*sab->delete_op_root_relpath = NULL;
 
   {
 svn_sqlite__stmt_t *stmt;




svn commit: r1152026 - /subversion/trunk/subversion/libsvn_client/commit.c

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 22:35:57 2011
New Revision: 1152026

URL: http://svn.apache.org/viewvc?rev=1152026&view=rev
Log:
Make commit refuse to commit the copied-half of a move independently of
the delete-half.

It is still possible to commit the delete-half independently of the
copied-half. That will be fixed soon.

This is the first visible behaviour change for moves.
None of our existing tests trigger the new error condition so writing
new tests wouldn't be a bad idea. I'll add some if nobody beats me to it.

* subversion/libsvn_client/commit.c
  (svn_client_commit5): Raise an error if the delete-half corresponding
   to the copied-half of a moved commit target does not appear in the
   commit target list.

Modified:
subversion/trunk/subversion/libsvn_client/commit.c

Modified: subversion/trunk/subversion/libsvn_client/commit.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/commit.c?rev=1152026&r1=1152025&r2=1152026&view=diff
==
--- subversion/trunk/subversion/libsvn_client/commit.c (original)
+++ subversion/trunk/subversion/libsvn_client/commit.c Thu Jul 28 22:35:57 2011
@@ -1356,6 +1356,47 @@ svn_client_commit5(const apr_array_heade
   goto cleanup;
   }
 
+  /* For every target that was moved verify that both halves of the
+   * move are part of the commit. */
+  for (i = 0; i < commit_items->nelts; i++)
+{
+  svn_client_commit_item3_t *item =
+APR_ARRAY_IDX(commit_items, i, svn_client_commit_item3_t *);
+
+  svn_pool_clear(iterpool);
+
+  if (item->state_flags & SVN_CLIENT_COMMIT_ITEM_IS_COPY)
+{
+  const char *moved_from_abspath;
+  const char *delete_op_root_abspath;
+
+  cmt_err = svn_error_trace(svn_wc__node_was_moved_here(
+  &moved_from_abspath,
+  &delete_op_root_abspath,
+  ctx->wc_ctx, item->path,
+  iterpool, iterpool));
+  if (cmt_err)
+goto cleanup;
+
+  if (moved_from_abspath && delete_op_root_abspath &&
+  strcmp(moved_from_abspath, delete_op_root_abspath) == 0 &&
+  apr_hash_get(committables->by_path, delete_op_root_abspath,
+   APR_HASH_KEY_STRING) == NULL)
+{
+  cmt_err = svn_error_createf(
+  SVN_ERR_ILLEGAL_TARGET, NULL,
+  _("Cannot commit '%s' because it was moved from "
+"'%s' which is not part of the commit; both "
+"sides of the move must be committed together"),
+  svn_dirent_local_style(item->path, iterpool),
+  svn_dirent_local_style(delete_op_root_abspath,
+ iterpool));
+  goto cleanup;
+}
+}
+  /* ### TODO: check the delete-half, too */
+}
+
   /* Go get a log message.  If an error occurs, or no log message is
  specified, abort the operation. */
   if (SVN_CLIENT__HAS_LOG_MSG_FUNC(ctx))




svn commit: r1152025 - /subversion/branches/1.7.x/STATUS

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 22:34:55 2011
New Revision: 1152025

URL: http://svn.apache.org/viewvc?rev=1152025&view=rev
Log:
Vote

Modified:
subversion/branches/1.7.x/STATUS

Modified: subversion/branches/1.7.x/STATUS
URL: 
http://svn.apache.org/viewvc/subversion/branches/1.7.x/STATUS?rev=1152025&r1=1152024&r2=1152025&view=diff
==
--- subversion/branches/1.7.x/STATUS (original)
+++ subversion/branches/1.7.x/STATUS Thu Jul 28 22:34:55 2011
@@ -153,13 +153,6 @@ Candidate changes:
Votes:
  +1: rhuijben, danielsh
 
- * r1150812
-   Issue 3972, spurious revert notification on symlinks
-   Justification:
- A regression from 1.6.
-   Votes:
- +1: philip, stsp
-
  * r1151177
Fix two bugs in ra_serf when connecting to HTTPS repository hosted on
non-standard port.
@@ -219,3 +212,11 @@ Approved changes:
  this revision depends for a clean merge).
Votes:
  +1: rhuijben, danielsh, cmpilato
+
+ * r1150812
+   Issue 3972, spurious revert notification on symlinks
+   Justification:
+ A regression from 1.6.
+   Votes:
+ +1: philip, stsp, danielsh
+




svn commit: r1152023 - /subversion/trunk/subversion/libsvn_wc/wc_db.c

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 22:27:14 2011
New Revision: 1152023

URL: http://svn.apache.org/viewvc?rev=1152023&view=rev
Log:
* subversion/libsvn_wc/wc_db.c
  (svn_wc__db_scan_addition): Do not dereference MOVED_FROM_RELPATH
and DELETE_OP_ROOT_RELPATH if scan_deletion() set them to NULL.

Modified:
subversion/trunk/subversion/libsvn_wc/wc_db.c

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.c?rev=1152023&r1=1152022&r2=1152023&view=diff
==
--- subversion/trunk/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.c Thu Jul 28 22:27:14 2011
@@ -9442,11 +9442,11 @@ svn_wc__db_scan_addition(svn_wc__db_stat
wcroot->sdb, original_repos_id,
result_pool));
 
-  if (moved_from_abspath)
+  if (moved_from_abspath && moved_from_relpath)
 *moved_from_abspath = svn_dirent_join(wcroot->abspath,
   moved_from_relpath,
   result_pool);
-  if (delete_op_root_abspath)
+  if (delete_op_root_abspath && delete_op_root_relpath)
 *delete_op_root_abspath = svn_dirent_join(wcroot->abspath,
   delete_op_root_relpath,
   result_pool);




svn commit: r1152016 [3/5] - in /subversion/branches/revprop-packing: ./ build/ build/ac-macros/ build/generator/ build/generator/swig/ notes/ subversion/bindings/swig/ subversion/bindings/swig/perl/n

2011-07-28 Thread danielsh
Modified: subversion/branches/revprop-packing/subversion/libsvn_wc/copy.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/subversion/libsvn_wc/copy.c?rev=1152016&r1=1152015&r2=1152016&view=diff
==
--- subversion/branches/revprop-packing/subversion/libsvn_wc/copy.c (original)
+++ subversion/branches/revprop-packing/subversion/libsvn_wc/copy.c Thu Jul 28 
21:58:49 2011
@@ -312,14 +312,9 @@ copy_versioned_file(svn_wc__db_t *db,
 
   /* Copy the (single) node's metadata, and move the new filesystem node
  into place. */
-  if (is_move)
-SVN_ERR(svn_wc__db_op_move(db, src_abspath, dst_abspath,
-   dst_op_root_abspath, work_items,
-   scratch_pool));
-  else
-SVN_ERR(svn_wc__db_op_copy(db, src_abspath, dst_abspath,
-   dst_op_root_abspath, work_items,
-   scratch_pool));
+  SVN_ERR(svn_wc__db_op_copy(db, src_abspath, dst_abspath,
+ dst_op_root_abspath, is_move, work_items,
+ scratch_pool));
   SVN_ERR(svn_wc__wq_run(db, dir_abspath,
  cancel_func, cancel_baton, scratch_pool));
 
@@ -383,14 +378,9 @@ copy_versioned_dir(svn_wc__db_t *db,
 
   /* Copy the (single) node's metadata, and move the new filesystem node
  into place. */
-  if (is_move)
-SVN_ERR(svn_wc__db_op_move(db, src_abspath, dst_abspath,
-   dst_op_root_abspath, work_items,
-   scratch_pool));
-  else
-SVN_ERR(svn_wc__db_op_copy(db, src_abspath, dst_abspath,
-   dst_op_root_abspath, work_items,
-   scratch_pool));
+  SVN_ERR(svn_wc__db_op_copy(db, src_abspath, dst_abspath,
+ dst_op_root_abspath, is_move, work_items,
+ scratch_pool));
   SVN_ERR(svn_wc__wq_run(db, dir_abspath,
  cancel_func, cancel_baton, scratch_pool));
 
@@ -499,14 +489,9 @@ copy_versioned_dir(svn_wc__db_t *db,
 {
   /* This will be copied as some kind of deletion. Don't touch
  any actual files */
-  if (is_move)
-SVN_ERR(svn_wc__db_op_move(db, child_src_abspath,
-   child_dst_abspath, dst_op_root_abspath,
-   NULL, scratch_pool));
-  else
-SVN_ERR(svn_wc__db_op_copy(db, child_src_abspath,
-   child_dst_abspath, dst_op_root_abspath,
-   NULL, iterpool));
+  SVN_ERR(svn_wc__db_op_copy(db, child_src_abspath,
+ child_dst_abspath, dst_op_root_abspath,
+ is_move, NULL, iterpool));
 
   /* Don't recurse on children while all we do is creating not-present
  children */
@@ -657,7 +642,7 @@ copy_or_move(svn_wc_context_t *wc_ctx,
   SVN_ERR(svn_wc__db_scan_addition(NULL, NULL, NULL,
&src_repos_root_url,
&src_repos_uuid, NULL, NULL, NULL,
-   NULL,
+   NULL, NULL, NULL,
db, src_abspath,
scratch_pool, scratch_pool));
 else
@@ -674,7 +659,7 @@ copy_or_move(svn_wc_context_t *wc_ctx,
   SVN_ERR(svn_wc__db_scan_addition(NULL, NULL, NULL,
&dst_repos_root_url,
&dst_repos_uuid, NULL, NULL, NULL,
-   NULL,
+   NULL, NULL, NULL,
db, dstdir_abspath,
scratch_pool, scratch_pool));
 else
@@ -1006,10 +991,11 @@ svn_wc_move(svn_wc_context_t *wc_ctx,
scratch_pool));
   }
 
-  SVN_ERR(svn_wc_delete4(wc_ctx, src_abspath, TRUE, FALSE,
- cancel_func, cancel_baton,
- notify_func, notify_baton,
- scratch_pool));
+  SVN_ERR(svn_wc__delete_internal(wc_ctx, src_abspath, TRUE, FALSE,
+  dst_abspath,
+  cancel_func, cancel_baton,
+  notify_func, notify_baton,
+  scratch_pool));
 
   return SVN_NO_ERROR;
 }

Modified: subversion/branches/revprop-packing/subversion/libsvn_wc/diff_editor.c
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/subversion/libsvn_wc/diff_editor.c?rev=1152016&r1=1152015&r2=1152016&view=diff
==

svn commit: r1152016 [5/5] - in /subversion/branches/revprop-packing: ./ build/ build/ac-macros/ build/generator/ build/generator/swig/ notes/ subversion/bindings/swig/ subversion/bindings/swig/perl/n

2011-07-28 Thread danielsh
Modified: 
subversion/branches/revprop-packing/subversion/tests/cmdline/externals_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/subversion/tests/cmdline/externals_tests.py?rev=1152016&r1=1152015&r2=1152016&view=diff
==
--- 
subversion/branches/revprop-packing/subversion/tests/cmdline/externals_tests.py 
(original)
+++ 
subversion/branches/revprop-packing/subversion/tests/cmdline/externals_tests.py 
Thu Jul 28 21:58:49 2011
@@ -28,7 +28,6 @@
 import sys
 import os
 import re
-import tempfile
 
 # Our testing module
 import svntest
@@ -214,25 +213,18 @@ def externals_test_setup(sbox):
 def change_external(path, new_val, commit=True):
   """Change the value of the externals property on PATH to NEW_VAL,
   and commit the change unless COMMIT is False."""
-  (fd, tmp_f) = tempfile.mkstemp(dir=svntest.main.temp_dir)
-  svntest.main.file_append(tmp_f, new_val)
-  svntest.actions.run_and_verify_svn(None, None, [], 'pset',
- '-F', tmp_f, 'svn:externals', path)
+
+  svntest.actions.set_prop('svn:externals', new_val, path)
   if commit:
 svntest.actions.run_and_verify_svn(None, None, [], 'ci',
'-m', 'log msg', '--quiet', path)
-  os.close(fd)
-  os.remove(tmp_f)
 
 def change_external_expect_error(path, new_val, expected_err):
   """Try to change the value of the externals property on PATH to NEW_VAL,
   but expect to get an error message that matches EXPECTED_ERR."""
-  (fd, tmp_f) = tempfile.mkstemp(dir=svntest.main.temp_dir)
-  svntest.main.file_append(tmp_f, new_val)
-  svntest.actions.run_and_verify_svn(None, None, expected_err, 'pset',
- '-F', tmp_f, 'svn:externals', path)
-  os.close(fd)
-  os.remove(tmp_f)
+
+  svntest.actions.set_prop('svn:externals', new_val, path,
+   expected_err=expected_err)
 
 
 def probe_paths_exist(paths):

Modified: 
subversion/branches/revprop-packing/subversion/tests/cmdline/getopt_tests_data/svn_help_log_switch_stdout
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/subversion/tests/cmdline/getopt_tests_data/svn_help_log_switch_stdout?rev=1152016&r1=1152015&r2=1152016&view=diff
==
--- 
subversion/branches/revprop-packing/subversion/tests/cmdline/getopt_tests_data/svn_help_log_switch_stdout
 (original)
+++ 
subversion/branches/revprop-packing/subversion/tests/cmdline/getopt_tests_data/svn_help_log_switch_stdout
 Thu Jul 28 21:58:49 2011
@@ -87,8 +87,9 @@ Global options:
   --password ARG   : specify a password ARG
   --no-auth-cache  : do not cache authentication tokens
   --non-interactive: do no interactive prompting
-  --trust-server-cert  : accept unknown SSL server certificates without
- prompting (but only with '--non-interactive')
+  --trust-server-cert  : accept SSL server certificates from unknown
+ certificate authorities without prompting (but 
only
+ with '--non-interactive')
   --config-dir ARG : read user configuration files from directory ARG
   --config-option ARG  : set user configuration option in the format:
  FILE:SECTION:OPTION=[VALUE]
@@ -165,8 +166,9 @@ Global options:
   --password ARG   : specify a password ARG
   --no-auth-cache  : do not cache authentication tokens
   --non-interactive: do no interactive prompting
-  --trust-server-cert  : accept unknown SSL server certificates without
- prompting (but only with '--non-interactive')
+  --trust-server-cert  : accept SSL server certificates from unknown
+ certificate authorities without prompting (but 
only
+ with '--non-interactive')
   --config-dir ARG : read user configuration files from directory ARG
   --config-option ARG  : set user configuration option in the format:
  FILE:SECTION:OPTION=[VALUE]

Modified: 
subversion/branches/revprop-packing/subversion/tests/cmdline/info_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/subversion/tests/cmdline/info_tests.py?rev=1152016&r1=1152015&r2=1152016&view=diff
==
--- subversion/branches/revprop-packing/subversion/tests/cmdline/info_tests.py 
(original)
+++ subversion/branches/revprop-packing/subversion/tests/cmdline/info_tests.py 
Thu Jul 28 21:58:49 2011
@@ -449,8 +449,8 @@ def info_show_exclude(sbox):
 
   expected_info = [{
   'Path' : '.*%siota' % re.escape(os.sep),
- 'Repository Root' : sbox.repo_url,
- 'Repository UUID' : wc_uuid,
+  'Repository Root' : sbox.repo_url,
+  

svn commit: r1152013 - in /subversion/branches/revprop-packing: ./ subversion/include/private/ subversion/libsvn_fs_fs/ subversion/libsvn_subr/

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 21:47:40 2011
New Revision: 1152013

URL: http://svn.apache.org/viewvc?rev=1152013&view=rev
Log:
On the revprop-packing branch, block r1151667 r1151948 from trunk.

Modified:
subversion/branches/revprop-packing/   (props changed)

subversion/branches/revprop-packing/subversion/include/private/svn_adler32.h   
(props changed)

subversion/branches/revprop-packing/subversion/include/private/svn_string_private.h
   (props changed)

subversion/branches/revprop-packing/subversion/include/private/svn_temp_serializer.h
   (props changed)

subversion/branches/revprop-packing/subversion/libsvn_fs_fs/temp_serializer.c   
(props changed)

subversion/branches/revprop-packing/subversion/libsvn_fs_fs/temp_serializer.h   
(props changed)
subversion/branches/revprop-packing/subversion/libsvn_subr/adler32.c   
(props changed)

subversion/branches/revprop-packing/subversion/libsvn_subr/svn_temp_serializer.c
   (props changed)

Propchange: subversion/branches/revprop-packing/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Jul 28 21:47:40 2011
@@ -52,4 +52,4 @@
 /subversion/branches/tree-conflicts:868291-873154
 /subversion/branches/tree-conflicts-notify:873926-874008
 /subversion/branches/uris-as-urls:1060426-1064427
-/subversion/trunk:1143817-1148765,1151672,1151680,1151916,1151954,1151957
+/subversion/trunk:1143817-1148765,1151667,1151672,1151680,1151916,1151948,1151954,1151957

Propchange: 
subversion/branches/revprop-packing/subversion/include/private/svn_adler32.h
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Jul 28 21:47:40 2011
@@ -43,4 +43,4 @@
 /subversion/branches/tc_url_rev/subversion/libsvn_diff/diff.h:874351-874483
 /subversion/branches/tree-conflicts/subversion/libsvn_diff/diff.h:868291-873154
 
/subversion/branches/tree-conflicts-notify/subversion/libsvn_diff/diff.h:873926-874008
-/subversion/trunk/subversion/include/private/svn_adler32.h:1143817-1148765
+/subversion/trunk/subversion/include/private/svn_adler32.h:1143817-1148765,1151667,1151948

Propchange: 
subversion/branches/revprop-packing/subversion/include/private/svn_string_private.h
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Jul 28 21:47:40 2011
@@ -52,4 +52,4 @@
 
/subversion/branches/tree-conflicts/subversion/include/svn_string.h:868291-873154
 
/subversion/branches/tree-conflicts-notify/subversion/include/svn_string.h:873926-874008
 
/subversion/branches/uris-as-urls/subversion/include/svn_string.h:1060426-1064427
-/subversion/trunk/subversion/include/private/svn_string_private.h:1143817-1148765
+/subversion/trunk/subversion/include/private/svn_string_private.h:1143817-1148765,1151667,1151948

Propchange: 
subversion/branches/revprop-packing/subversion/include/private/svn_temp_serializer.h
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Jul 28 21:47:40 2011
@@ -1 +1 @@
-/subversion/trunk/subversion/include/private/svn_temp_serializer.h:1067687-1072301,1143817-1148765
+/subversion/trunk/subversion/include/private/svn_temp_serializer.h:1067687-1072301,1143817-1148765,1151667,1151948

Propchange: 
subversion/branches/revprop-packing/subversion/libsvn_fs_fs/temp_serializer.c
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Jul 28 21:47:40 2011
@@ -1 +1 @@
-/subversion/trunk/subversion/libsvn_fs_fs/temp_serializer.c:1067687-1072301,1143817-1148765
+/subversion/trunk/subversion/libsvn_fs_fs/temp_serializer.c:1067687-1072301,1143817-1148765,1151667,1151948

Propchange: 
subversion/branches/revprop-packing/subversion/libsvn_fs_fs/temp_serializer.h
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Jul 28 21:47:40 2011
@@ -1 +1 @@
-/subversion/trunk/subversion/libsvn_fs_fs/temp_serializer.h:1067687-1072301,1143817-1148765
+/subversion/trunk/subversion/libsvn_fs_fs/temp_serializer.h:1067687-1072301,1143817-1148765,1151667,1151948

Propchange: subversion/branches/revprop-packing/subversion/libsvn_subr/adler32.c
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Jul 28 21:47:40 2011
@@ -1,4 +1,4 @@
 
/subversion/branches/diff-optimizations/subversion/libsvn_subr/adler32.c:1031270-1037352
 
/subversion/branches/diff-optimizations-bytes/subversion/libsvn_subr/adler32.c:1037353-1067789
 
/subversion/branches/performance/subversion/libsvn_subr/adler32.c:1067697-1078365
-/subversion/trunk/subversion/libsvn_subr/adler32.c:1143817-1148765
+/subversion/trunk/subversion/libsvn_subr/adler32.c:1143817-1148765,1151667,1151948

Propchange: 
subve

svn propchange: r1152011 - svn:log

2011-07-28 Thread danielsh
Author: danielsh
Revision: 1152011
Modified property: svn:log

Modified: svn:log at Thu Jul 28 21:42:36 2011
--
--- svn:log (original)
+++ svn:log Thu Jul 28 21:42:36 2011
@@ -1,2 +1,2 @@
 On the revprop-packing branch, merge r1144572 from trunk,
-using a 1.7.0-beta1 client.
+using a trunk client.



svn commit: r1152011 - /subversion/branches/revprop-packing/subversion/libsvn_subr/hash.c

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 21:42:04 2011
New Revision: 1152011

URL: http://svn.apache.org/viewvc?rev=1152011&view=rev
Log:
On the revprop-packing branch, merge r1144572 from trunk,
using a 1.7.0-beta1 client.

Modified:
subversion/branches/revprop-packing/subversion/libsvn_subr/hash.c   (props 
changed)

Propchange: subversion/branches/revprop-packing/subversion/libsvn_subr/hash.c
('svn:mergeinfo' removed)




svn commit: r1152001 - in /subversion/branches/revprop-packing: ./ build/run_tests.py subversion/tests/cmdline/svntest/main.py

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 21:05:14 2011
New Revision: 1152001

URL: http://svn.apache.org/viewvc?rev=1152001&view=rev
Log:
On the revprop-packing branch, merge r1151916 r1151954 r1151957 from trunk,
resolving conflicts, with a 1.7.0-beta1 client.

Modified:
subversion/branches/revprop-packing/   (props changed)
subversion/branches/revprop-packing/build/run_tests.py
subversion/branches/revprop-packing/subversion/tests/cmdline/svntest/main.py

Propchange: subversion/branches/revprop-packing/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Thu Jul 28 21:05:14 2011
@@ -52,4 +52,4 @@
 /subversion/branches/tree-conflicts:868291-873154
 /subversion/branches/tree-conflicts-notify:873926-874008
 /subversion/branches/uris-as-urls:1060426-1064427
-/subversion/trunk:1143817-1148765,1151672,1151680
+/subversion/trunk:1143817-1148765,1151672,1151680,1151916,1151954,1151957

Modified: subversion/branches/revprop-packing/build/run_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/build/run_tests.py?rev=1152001&r1=1152000&r2=1152001&view=diff
==
--- subversion/branches/revprop-packing/build/run_tests.py (original)
+++ subversion/branches/revprop-packing/build/run_tests.py Thu Jul 28 21:05:14 
2011
@@ -44,6 +44,7 @@ separated list of test numbers; the defa
 
 # A few useful constants
 LINE_LENGTH = 45
+SVN_VER_MINOR = 8
 
 import os, re, subprocess, sys, imp
 from datetime import datetime
@@ -111,8 +112,9 @@ class TestHarness:
 # If you change the below condition then change in
 # ../subversion/tests/cmdline/svntest/main.py too.
 if server_minor_version is not None:
-  if int(server_minor_version) < 3 or int(server_minor_version) > 7:
-sys.stderr.write("Test harness only supports server minor versions 
3-7\n")
+  if int(server_minor_version) not in range(3, 1+SVN_VER_MINOR):
+sys.stderr.write("Test harness only supports server minor versions 
3-%d\n"
+ % SVN_VER_MINOR)
 sys.exit(1)
 self.verbose = verbose
 self.cleanup = cleanup

Modified: 
subversion/branches/revprop-packing/subversion/tests/cmdline/svntest/main.py
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/subversion/tests/cmdline/svntest/main.py?rev=1152001&r1=1152000&r2=1152001&view=diff
==
--- 
subversion/branches/revprop-packing/subversion/tests/cmdline/svntest/main.py 
(original)
+++ 
subversion/branches/revprop-packing/subversion/tests/cmdline/svntest/main.py 
Thu Jul 28 21:05:14 2011
@@ -51,6 +51,7 @@ import svntest
 from svntest import Failure
 from svntest import Skip
 
+SVN_VER_MINOR = 8
 
 ##
 #
@@ -1500,8 +1501,8 @@ def _create_parser():
  "it supports both, else assume it's using this " +
  "one; the default is " + _default_http_library)
   parser.add_option('--server-minor-version', type='int', action='store',
-help="Set the minor version for the server ('4', " +
- "'5', or '6').")
+help="Set the minor version for the server ('3'..'%d')."
+% SVN_VER_MINOR)
   parser.add_option('--fsfs-packing', action='store_true',
 help="Run 'svnadmin pack' automatically")
   parser.add_option('--fsfs-sharding', action='store', type='int',
@@ -1521,7 +1522,7 @@ def _create_parser():
 
   # most of the defaults are None, but some are other values, set them here
   parser.set_defaults(
-server_minor_version=float('+inf'), # positive infinity
+server_minor_version=SVN_VER_MINOR,
 url=file_scheme_prefix + pathname2url(os.path.abspath(os.getcwd())),
 http_library=_default_http_library)
 
@@ -1545,9 +1546,9 @@ def _parse_options(arglist=sys.argv[1:])
 
   # If you change the below condition then change
   # ../../../../build/run_tests.py too.
-  if (options.server_minor_version < 3 or options.server_minor_version > 7) \
-  and options.server_minor_version != float('inf'):
-parser.error("test harness only supports server minor versions 3-7")
+  if options.server_minor_version not in range(3, SVN_VER_MINOR+1):
+parser.error("test harness only supports server minor versions 3-%d"
+ % SVN_VER_MINOR)
 
   if options.url:
 if options.url[-1:] == '/': # Normalize url to have no trailing slash




svn propchange: r1151970 - svn:log

2011-07-28 Thread danielsh
Author: danielsh
Revision: 1151970
Modified property: svn:log

Modified: svn:log at Thu Jul 28 19:00:47 2011
--
--- svn:log (original)
+++ svn:log Thu Jul 28 19:00:47 2011
@@ -1,2 +1,2 @@
-* site/public/roadmap.html: Add conflict-storage to 1.8 items (not-started).
+* site/publish/roadmap.html: Add conflict-storage to 1.8 items (not-started).
Let's hope we'll get to it in this release cycle.



svn commit: r1151972 - /subversion/site/publish/roadmap.html

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 18:59:55 2011
New Revision: 1151972

URL: http://svn.apache.org/viewvc?rev=1151972&view=rev
Log:
* publish/roadmap.html: Link FSFS revprop packing to issue #3944.

Modified:
subversion/site/publish/roadmap.html

Modified: subversion/site/publish/roadmap.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/roadmap.html?rev=1151972&r1=1151971&r2=1151972&view=diff
==
--- subversion/site/publish/roadmap.html (original)
+++ subversion/site/publish/roadmap.html Thu Jul 28 18:59:55 2011
@@ -481,7 +481,8 @@ numbering, compatibility, and deprecatio
   
 FSFS: Packing of revision property shards
 In Progress
-
+http://subversion.tigris.org/issues/show_bug.cgi?id=3944";
+>Issue 3944
   
   
 Improved handling of local moves/renames




svn commit: r1151971 - /subversion/site/publish/roadmap.html

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 18:52:55 2011
New Revision: 1151971

URL: http://svn.apache.org/viewvc?rev=1151971&view=rev
Log:
* publish/roadmap.html: & -> &
Found by: danielsh

Modified:
subversion/site/publish/roadmap.html

Modified: subversion/site/publish/roadmap.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/roadmap.html?rev=1151971&r1=1151970&r2=1151971&view=diff
==
--- subversion/site/publish/roadmap.html (original)
+++ subversion/site/publish/roadmap.html Thu Jul 28 18:52:55 2011
@@ -475,7 +475,7 @@ numbering, compatibility, and deprecatio
   
 GPG Agent support
 Completed
-See comment added in http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/gpg_agent.c?r1=1151053&r2=1151069";
+See comment added in http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/gpg_agent.c?r1=1151053&r2=1151069";
 >this commit for more information.
   
   




svn commit: r1151970 - /subversion/site/publish/roadmap.html

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 18:51:06 2011
New Revision: 1151970

URL: http://svn.apache.org/viewvc?rev=1151970&view=rev
Log:
* site/public/roadmap.html: Add conflict-storage to 1.8 items (not-started).
   Let's hope we'll get to it in this release cycle.

Modified:
subversion/site/publish/roadmap.html

Modified: subversion/site/publish/roadmap.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/roadmap.html?rev=1151970&r1=1151969&r2=1151970&view=diff
==
--- subversion/site/publish/roadmap.html (original)
+++ subversion/site/publish/roadmap.html Thu Jul 28 18:51:06 2011
@@ -490,6 +490,12 @@ numbering, compatibility, and deprecatio
 >Issue 3631
   
   
+Conflict storage
+Not Started
+Design spec is http://svn.apache.org/repos/asf/subversion/trunk/notes/wc-ng/conflict-storage";
+   >here. Implementation was planned for 1.7 but didn't make it.
+  
+  
 Review of performance branch
 Not Started
 Review items on the http://svn.apache.org/repos/asf/subversion/branches/performance/";>performance
 branch,




svn commit: r1151966 - /subversion/site/publish/roadmap.html

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 18:45:36 2011
New Revision: 1151966

URL: http://svn.apache.org/viewvc?rev=1151966&view=rev
Log:
* site/publish/roadmap.html: Fix typo from r1151965.

Modified:
subversion/site/publish/roadmap.html

Modified: subversion/site/publish/roadmap.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/roadmap.html?rev=1151966&r1=1151965&r2=1151966&view=diff
==
--- subversion/site/publish/roadmap.html (original)
+++ subversion/site/publish/roadmap.html Thu Jul 28 18:45:36 2011
@@ -475,7 +475,7 @@ numbering, compatibility, and deprecatio
   
 GPG Agent support
 Completed
-See comment added in http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/gpg_agent.c?r1=1151053&r2=1151069";>
+See comment added in http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/gpg_agent.c?r1=1151053&r2=1151069";
 >this commit for more information.
   
   




svn commit: r1151965 - /subversion/site/publish/roadmap.html

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 18:44:35 2011
New Revision: 1151965

URL: http://svn.apache.org/viewvc?rev=1151965&view=rev
Log:
* site/publish/roadmap.html: Add a note to GPG-Agent entry in 1.8 table.

Modified:
subversion/site/publish/roadmap.html

Modified: subversion/site/publish/roadmap.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/roadmap.html?rev=1151965&r1=1151964&r2=1151965&view=diff
==
--- subversion/site/publish/roadmap.html (original)
+++ subversion/site/publish/roadmap.html Thu Jul 28 18:44:35 2011
@@ -475,7 +475,8 @@ numbering, compatibility, and deprecatio
   
 GPG Agent support
 Completed
-
+See comment added in http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/gpg_agent.c?r1=1151053&r2=1151069";>
+>this commit for more information.
   
   
 FSFS: Packing of revision property shards




svn commit: r1151964 - /subversion/site/publish/docs/community-guide/releasing.part.html

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 18:43:22 2011
New Revision: 1151964

URL: http://svn.apache.org/viewvc?rev=1151964&view=rev
Log:
More work for Hyrum.

* docs/community-guide/releasing.part.html
  (release-branches): Need to update the Python tests' notion of 
SVN_MINOR_NUMBER too.

Automated by: danielsh

Modified:
subversion/site/publish/docs/community-guide/releasing.part.html

Modified: subversion/site/publish/docs/community-guide/releasing.part.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/docs/community-guide/releasing.part.html?rev=1151964&r1=1151963&r2=1151964&view=diff
==
--- subversion/site/publish/docs/community-guide/releasing.part.html (original)
+++ subversion/site/publish/docs/community-guide/releasing.part.html Thu Jul 28 
18:43:22 2011
@@ -1077,6 +1077,11 @@ A.B with the version you're preparing, e
 created a branch (eg. 2.1.0 for the 2.0.x branch, and 1.4.0 for
 the 1.3.x branch).
 
+Edit build/run_tests.py and
+subversion/tests/cmdline/svntest/main.py on trunk and
+increment SVN_VER_MINOR.  Do not commit these changes
+yet.
+
 Edit CHANGES on trunk to introduce a new section for the
 upcoming release.  The section starts with:
 
@@ -1093,6 +1098,10 @@ A.B with the version you're preparing, e
 
   * subversion/include/svn_version.h: Increment version number.
 
+  * subversion/tests/cmdline/svntest/main.py (SVN_VER_MINOR),
+build/run_tests.py (SVN_VER_MINOR):
+  Increment version number.
+
   * CHANGES: New section for A.B.0.
 
 




svn commit: r1151962 - /subversion/trunk/notes/moves

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 18:40:56 2011
New Revision: 1151962

URL: http://svn.apache.org/viewvc?rev=1151962&view=rev
Log:
* notes/moves: Mention number of the issue which corresponds to this.

Modified:
subversion/trunk/notes/moves

Modified: subversion/trunk/notes/moves
URL: 
http://svn.apache.org/viewvc/subversion/trunk/notes/moves?rev=1151962&r1=1151961&r2=1151962&view=diff
==
--- subversion/trunk/notes/moves (original)
+++ subversion/trunk/notes/moves Thu Jul 28 18:40:56 2011
@@ -7,7 +7,7 @@ This file purposefully talks about 'move
 This isn't about true renames as requested in issue #898.
 Rather, these ideas keep the add+delete concept while trying to make
 moves behave more in a way that one would expect if true renames were
-implemented.
+implemented, as requested in issue #3631.
 
 These ideas only cover local (client-side) moves in the working copy.
 They attempt to reuse as much existing code as possible, so new




svn commit: r1151961 - /subversion/site/publish/docs/community-guide/releasing.toc.html

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 18:36:59 2011
New Revision: 1151961

URL: http://svn.apache.org/viewvc?rev=1151961&view=rev
Log:
* docs/community-guide/releasing.toc.html: Fix a missing link.

TODO: script the generation and/or checking of these 2-TOC-lists-per-page.

Modified:
subversion/site/publish/docs/community-guide/releasing.toc.html

Modified: subversion/site/publish/docs/community-guide/releasing.toc.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/docs/community-guide/releasing.toc.html?rev=1151961&r1=1151960&r2=1151961&view=diff
==
--- subversion/site/publish/docs/community-guide/releasing.toc.html (original)
+++ subversion/site/publish/docs/community-guide/releasing.toc.html Thu Jul 28 
18:36:59 2011
@@ -25,6 +25,7 @@
   Preparing to roll a 
release
   Rolling a release
   The actual releasing
+  After a release has been 
made
   How not to make a 
Subversion release
 
 




Re: svn commit: r1151916 - /subversion/trunk/subversion/tests/cmdline/svntest/main.py

2011-07-28 Thread Daniel Shahaf
julianf...@apache.org wrote on Thu, Jul 28, 2011 at 16:37:56 -:
> Author: julianfoad
> Date: Thu Jul 28 16:37:55 2011
> New Revision: 1151916
> 
> URL: http://svn.apache.org/viewvc?rev=1151916&view=rev
> Log:
> Revert r1151672 and r1151680 which made the test suite fail to run all or
> many of the Python tests while still reporting success.
> 
> The original combined log message of the two revs was effectively:
> 
>   Bump the Python tests' equivalent of SVN_VER_MINOR.  Since I'm too
>   lazy to make this parse svn_version.h, opt for the least-maintenance
>   solution:
> 
>   * subversion/tests/cmdline/svntest/main.py
> (_create_parser): Make 'server_minor_version' default to inf (positive
>   infinity).
> (_parse_options): Account for the change.

The following patch seems to run properly both via 'make check' and via
running individual tests.  (It does pass --server-minor-version=inf
internally; I can address that later.)

[[[
Index: subversion/tests/cmdline/svntest/main.py
===
--- subversion/tests/cmdline/svntest/main.py(revision 1151954)
+++ subversion/tests/cmdline/svntest/main.py(working copy)
@@ -1515,7 +1515,7 @@ def _create_parser():
 
   # most of the defaults are None, but some are other values, set them here
   parser.set_defaults(
-server_minor_version=8,
+server_minor_version=float('+inf'), # positive infinity
 url=file_scheme_prefix + pathname2url(os.path.abspath(os.getcwd())),
 http_library=_default_http_library)
 
@@ -1539,8 +1539,9 @@ def _parse_options(arglist=sys.argv[1:]):
 
   # If you change the below condition then change
   # ../../../../build/run_tests.py too.
-  if options.server_minor_version < 3 or options.server_minor_version > 8:
-parser.error("test harness only supports server minor versions 3-8")
+  if options.server_minor_version not in (None, float('inf')):
+if options.server_minor_version < 3 or options.server_minor_version > 8:
+  parser.error("test harness only supports server minor versions 3-8")
 
   if options.url:
 if options.url[-1:] == '/': # Normalize url to have no trailing slash
Index: build/run_tests.py
===
--- build/run_tests.py  (revision 1151954)
+++ build/run_tests.py  (working copy)
@@ -110,7 +110,7 @@ class TestHarness:
 self.server_minor_version = server_minor_version
 # If you change the below condition then change in
 # ../subversion/tests/cmdline/svntest/main.py too.
-if server_minor_version is not None:
+if options.server_minor_version not in (None, float('inf')):
   if int(server_minor_version) < 3 or int(server_minor_version) > 8:
 sys.stderr.write("Test harness only supports server minor versions 
3-8\n")
 sys.exit(1)
@@ -311,7 +311,7 @@ class TestHarness:
 if self.fs_type is not None:
   cmdline.append('--fs-type=' + self.fs_type)
 if self.server_minor_version is not None:
-  cmdline.append('--server-minor-version=' + self.server_minor_version)
+  cmdline.append('--server-minor-version=' + 
str(self.server_minor_version))
 if self.list_tests is not None:
   cmdline.append('--list')
 if self.mode_filter is not None:
@@ -399,7 +399,7 @@ class TestHarness:
 if self.http_library is not None:
   svntest.main.options.http_library = self.http_library
 if self.server_minor_version is not None:
-  svntest.main.options.server_minor_version = 
int(self.server_minor_version)
+  svntest.main.options.server_minor_version = 
float(self.server_minor_version)
 if self.list_tests is not None:
   svntest.main.options.list_tests = True
 if self.milestone_filter is not None:
]]]

At this point, though, I decided that r1151957 would be the clearer approach.


svn commit: r1151960 - /subversion/site/publish/roadmap.html

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 18:36:37 2011
New Revision: 1151960

URL: http://svn.apache.org/viewvc?rev=1151960&view=rev
Log:
* site/publish/roadmap.html: Note that improved local move support is
   work-in-progress for 1.8.

Modified:
subversion/site/publish/roadmap.html

Modified: subversion/site/publish/roadmap.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/roadmap.html?rev=1151960&r1=1151959&r2=1151960&view=diff
==
--- subversion/site/publish/roadmap.html (original)
+++ subversion/site/publish/roadmap.html Thu Jul 28 18:36:37 2011
@@ -482,6 +482,11 @@ numbering, compatibility, and deprecatio
 In Progress
 
   
+  
+Improved handling of local moves/renames
+In Progress
+http://subversion.tigris.org/issues/show_bug.cgi?id=3631";
+>Issue 3631
   
   
 Review of performance branch




svn commit: r1151957 - in /subversion/trunk: build/run_tests.py subversion/tests/cmdline/svntest/main.py

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 18:33:31 2011
New Revision: 1151957

URL: http://svn.apache.org/viewvc?rev=1151957&view=rev
Log:
Factor out a magic number.

* build/run_tests.py
  (SVN_VER_MINOR): New.
  (TestHarness.__init__): Use it.

* subversion/tests/cmdline/svntest/main.py
  (SVN_VER_MINOR): New.
  (_create_parser, _parse_options): Use it.

Modified:
subversion/trunk/build/run_tests.py
subversion/trunk/subversion/tests/cmdline/svntest/main.py

Modified: subversion/trunk/build/run_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/build/run_tests.py?rev=1151957&r1=1151956&r2=1151957&view=diff
==
--- subversion/trunk/build/run_tests.py (original)
+++ subversion/trunk/build/run_tests.py Thu Jul 28 18:33:31 2011
@@ -44,6 +44,7 @@ separated list of test numbers; the defa
 
 # A few useful constants
 LINE_LENGTH = 45
+SVN_VER_MINOR = 8
 
 import os, re, subprocess, sys, imp
 from datetime import datetime
@@ -111,8 +112,9 @@ class TestHarness:
 # If you change the below condition then change in
 # ../subversion/tests/cmdline/svntest/main.py too.
 if server_minor_version is not None:
-  if int(server_minor_version) < 3 or int(server_minor_version) > 8:
-sys.stderr.write("Test harness only supports server minor versions 
3-8\n")
+  if int(server_minor_version) not in range(3, 1+SVN_VER_MINOR):
+sys.stderr.write("Test harness only supports server minor versions 
3-%d\n"
+ % SVN_VER_MINOR)
 sys.exit(1)
 self.verbose = verbose
 self.cleanup = cleanup

Modified: subversion/trunk/subversion/tests/cmdline/svntest/main.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/svntest/main.py?rev=1151957&r1=1151956&r2=1151957&view=diff
==
--- subversion/trunk/subversion/tests/cmdline/svntest/main.py (original)
+++ subversion/trunk/subversion/tests/cmdline/svntest/main.py Thu Jul 28 
18:33:31 2011
@@ -51,6 +51,7 @@ import svntest
 from svntest import Failure
 from svntest import Skip
 
+SVN_VER_MINOR = 8
 
 ##
 #
@@ -1495,7 +1496,8 @@ def _create_parser():
  "it supports both, else assume it's using this " +
  "one; the default is " + _default_http_library)
   parser.add_option('--server-minor-version', type='int', action='store',
-help="Set the minor version for the server ('3'..'8').")
+help="Set the minor version for the server ('3'..'%d')."
+% SVN_VER_MINOR)
   parser.add_option('--fsfs-packing', action='store_true',
 help="Run 'svnadmin pack' automatically")
   parser.add_option('--fsfs-sharding', action='store', type='int',
@@ -1515,7 +1517,7 @@ def _create_parser():
 
   # most of the defaults are None, but some are other values, set them here
   parser.set_defaults(
-server_minor_version=8,
+server_minor_version=SVN_VER_MINOR,
 url=file_scheme_prefix + pathname2url(os.path.abspath(os.getcwd())),
 http_library=_default_http_library)
 
@@ -1539,8 +1541,9 @@ def _parse_options(arglist=sys.argv[1:])
 
   # If you change the below condition then change
   # ../../../../build/run_tests.py too.
-  if options.server_minor_version < 3 or options.server_minor_version > 8:
-parser.error("test harness only supports server minor versions 3-8")
+  if options.server_minor_version not in range(3, SVN_VER_MINOR+1):
+parser.error("test harness only supports server minor versions 3-%d"
+ % SVN_VER_MINOR)
 
   if options.url:
 if options.url[-1:] == '/': # Normalize url to have no trailing slash




svn commit: r1151954 - in /subversion/trunk: build/run_tests.py subversion/tests/cmdline/svntest/main.py

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 18:19:25 2011
New Revision: 1151954

URL: http://svn.apache.org/viewvc?rev=1151954&view=rev
Log:
Unred the build.

* subversion/tests/cmdline/svntest/main.py
  (_create_parser, _parse_options): Accept '8' minor number.
Adjust helpstring.

* build/run_tests.py
  (TestHarness.__init__): Accept '8' minor number.

Modified:
subversion/trunk/build/run_tests.py
subversion/trunk/subversion/tests/cmdline/svntest/main.py

Modified: subversion/trunk/build/run_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/build/run_tests.py?rev=1151954&r1=1151953&r2=1151954&view=diff
==
--- subversion/trunk/build/run_tests.py (original)
+++ subversion/trunk/build/run_tests.py Thu Jul 28 18:19:25 2011
@@ -111,8 +111,8 @@ class TestHarness:
 # If you change the below condition then change in
 # ../subversion/tests/cmdline/svntest/main.py too.
 if server_minor_version is not None:
-  if int(server_minor_version) < 3 or int(server_minor_version) > 7:
-sys.stderr.write("Test harness only supports server minor versions 
3-7\n")
+  if int(server_minor_version) < 3 or int(server_minor_version) > 8:
+sys.stderr.write("Test harness only supports server minor versions 
3-8\n")
 sys.exit(1)
 self.verbose = verbose
 self.cleanup = cleanup

Modified: subversion/trunk/subversion/tests/cmdline/svntest/main.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/svntest/main.py?rev=1151954&r1=1151953&r2=1151954&view=diff
==
--- subversion/trunk/subversion/tests/cmdline/svntest/main.py (original)
+++ subversion/trunk/subversion/tests/cmdline/svntest/main.py Thu Jul 28 
18:19:25 2011
@@ -1495,8 +1495,7 @@ def _create_parser():
  "it supports both, else assume it's using this " +
  "one; the default is " + _default_http_library)
   parser.add_option('--server-minor-version', type='int', action='store',
-help="Set the minor version for the server ('4', " +
- "'5', '6', or '7').")
+help="Set the minor version for the server ('3'..'8').")
   parser.add_option('--fsfs-packing', action='store_true',
 help="Run 'svnadmin pack' automatically")
   parser.add_option('--fsfs-sharding', action='store', type='int',
@@ -1540,8 +1539,8 @@ def _parse_options(arglist=sys.argv[1:])
 
   # If you change the below condition then change
   # ../../../../build/run_tests.py too.
-  if options.server_minor_version < 3 or options.server_minor_version > 7:
-parser.error("test harness only supports server minor versions 3-7")
+  if options.server_minor_version < 3 or options.server_minor_version > 8:
+parser.error("test harness only supports server minor versions 3-8")
 
   if options.url:
 if options.url[-1:] == '/': # Normalize url to have no trailing slash




svn commit: r1151951 - in /subversion/trunk/subversion: include/private/svn_wc_private.h libsvn_wc/node.c

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 18:13:31 2011
New Revision: 1151951

URL: http://svn.apache.org/viewvc?rev=1151951&view=rev
Log:
Add new libsvn_wc API function svn_wc__node_was_moved_here() which
determines whether a node at a given LOCAL_ABSPATH was moved to this path.

This will be used later, and will also get a companion called
svn_wc__node_was_moved_away() (not implemented yet).

* subversion/include/private/svn_wc_private.h
  (svn_wc__node_was_moved_here): Declare.

* subversion/libsvn_wc/node.c
  (svn_wc__node_was_moved_here): New.

Modified:
subversion/trunk/subversion/include/private/svn_wc_private.h
subversion/trunk/subversion/libsvn_wc/node.c

Modified: subversion/trunk/subversion/include/private/svn_wc_private.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/include/private/svn_wc_private.h?rev=1151951&r1=1151950&r2=1151951&view=diff
==
--- subversion/trunk/subversion/include/private/svn_wc_private.h (original)
+++ subversion/trunk/subversion/include/private/svn_wc_private.h Thu Jul 28 
18:13:31 2011
@@ -,6 +,25 @@ svn_wc__delete_internal(svn_wc_context_t
 void *notify_baton,
 apr_pool_t *scratch_pool);
 
+/* If the node at LOCAL_ABSPATH was moved here set *MOVED_FROM_ABSPATH to
+ * the absolute path of the deleted move-source node, and set
+ * *DELETE_OP_ROOT_ABSPATH to the absolute path of the root node of the
+ * delete operation.
+ *
+ * If the node was not moved, set *MOVED_FROM_ABSPATH and
+ * *DELETE_OP_ROOT_ABSPATH to NULL.
+ *
+ * Either MOVED_FROM_ABSPATH or OP_ROOT_ABSPATH may be NULL to indicate
+ * that the caller is not interested in the result.
+ */
+svn_error_t *
+svn_wc__node_was_moved_here(const char **moved_from_abspath,
+const char **delete_op_root_abspath,
+svn_wc_context_t *wc_ctx,
+const char *local_abspath,
+apr_pool_t *result_pool,
+apr_pool_t *scratch_pool);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */

Modified: subversion/trunk/subversion/libsvn_wc/node.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/node.c?rev=1151951&r1=1151950&r2=1151951&view=diff
==
--- subversion/trunk/subversion/libsvn_wc/node.c (original)
+++ subversion/trunk/subversion/libsvn_wc/node.c Thu Jul 28 18:13:31 2011
@@ -1766,3 +1766,46 @@ svn_wc__check_for_obstructions(svn_wc_no
   return SVN_NO_ERROR;
 }
 
+
+svn_error_t *
+svn_wc__node_was_moved_here(const char **moved_from_abspath,
+const char **delete_op_root_abspath,
+svn_wc_context_t *wc_ctx,
+const char *local_abspath,
+apr_pool_t *result_pool,
+apr_pool_t *scratch_pool)
+{
+  svn_boolean_t is_added;
+
+  if (moved_from_abspath)
+*moved_from_abspath = NULL;
+  if (delete_op_root_abspath)
+*delete_op_root_abspath = NULL;
+
+  SVN_ERR(svn_wc__node_is_added(&is_added, wc_ctx, local_abspath,
+scratch_pool));
+  if (is_added && (moved_from_abspath || delete_op_root_abspath))
+{
+  svn_wc__db_status_t status;
+  const char *db_moved_from_abspath;
+  const char *db_delete_op_root_abspath;
+
+  SVN_ERR(svn_wc__db_scan_addition(&status, NULL,
+   NULL, NULL, NULL, NULL, NULL,
+   NULL, NULL, &db_moved_from_abspath,
+   &db_delete_op_root_abspath,
+   wc_ctx->db, local_abspath,
+   scratch_pool, scratch_pool));
+  if (status == svn_wc__db_status_moved_here)
+{
+  if (moved_from_abspath)
+*moved_from_abspath = apr_pstrdup(result_pool,
+  db_moved_from_abspath);
+  if (delete_op_root_abspath)
+*delete_op_root_abspath = apr_pstrdup(result_pool,
+  db_delete_op_root_abspath);
+}
+}
+
+  return SVN_NO_ERROR;
+}




svn commit: r1151948 - /subversion/trunk/subversion/tests/cmdline/svntest/main.py

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 18:09:08 2011
New Revision: 1151948

URL: http://svn.apache.org/viewvc?rev=1151948&view=rev
Log:
Follow-up to r1151672 and r1151680 (which were reverted in r1151916):

Until a better fix is devised, install a one-time fix that solves the immediate
problem --- '--pre-1.8-compatible' being erroneously used by default (on the
revprop-packing branch).

* subversion/tests/cmdline/svntest/main.py
  (_create_parser): Bump the minor version number to '8'.

Modified:
subversion/trunk/subversion/tests/cmdline/svntest/main.py

Modified: subversion/trunk/subversion/tests/cmdline/svntest/main.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/svntest/main.py?rev=1151948&r1=1151947&r2=1151948&view=diff
==
--- subversion/trunk/subversion/tests/cmdline/svntest/main.py (original)
+++ subversion/trunk/subversion/tests/cmdline/svntest/main.py Thu Jul 28 
18:09:08 2011
@@ -1516,7 +1516,7 @@ def _create_parser():
 
   # most of the defaults are None, but some are other values, set them here
   parser.set_defaults(
-server_minor_version=7,
+server_minor_version=8,
 url=file_scheme_prefix + pathname2url(os.path.abspath(os.getcwd())),
 http_library=_default_http_library)
 




svn commit: r1151946 - /subversion/site/publish/docs/release-notes/1.7.html

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 18:04:48 2011
New Revision: 1151946

URL: http://svn.apache.org/viewvc?rev=1151946&view=rev
Log:
* docs/release-notes/1.7.html
  (wc-pristines): Add text about periodic 'svn cleanup' and fix the section-id 
markers.

Modified:
subversion/site/publish/docs/release-notes/1.7.html

Modified: subversion/site/publish/docs/release-notes/1.7.html
URL: 
http://svn.apache.org/viewvc/subversion/site/publish/docs/release-notes/1.7.html?rev=1151946&r1=1151945&r2=1151946&view=diff
==
--- subversion/site/publish/docs/release-notes/1.7.html (original)
+++ subversion/site/publish/docs/release-notes/1.7.html Thu Jul 28 18:04:48 2011
@@ -438,7 +438,7 @@ result in working copy corruption.
 
  
 Pristine Contents
-  ¶ 
 
 
@@ -455,7 +455,13 @@ references to the pristine store, making
 smaller.  Running svn cleanup will remove any pristines which
 are no longer needed by the current state of the working copy.
 
-
+In 1.7, we recommend to run svn cleanup periodically in order to 
claim
+back the disk space of unreferenced pristines.  We expect a future Subversion
+release to purge unreferenced (and thus unused) pristines automatically; see
+http://subversion.tigris.org/issues/show_bug.cgi?id=XXX";>issue 
#XXX
+for details.
+
+  
 
  
 Upgrading the Working Copy




svn commit: r1151939 - /subversion/trunk/subversion/libsvn_wc/wc_db.c

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 17:51:08 2011
New Revision: 1151939

URL: http://svn.apache.org/viewvc?rev=1151939&view=rev
Log:
* subversion/libsvn_wc/wc_db.c
  (op_delete_txn): Remove local variable IS_VALID_MOVED_TO_RELPATH which
   I added in r1151824 but should have just left out. Its name is misleading,
   its purpose is bogus, and it was always TRUE in the code path where it
   was checked.

Modified:
subversion/trunk/subversion/libsvn_wc/wc_db.c

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.c?rev=1151939&r1=1151938&r2=1151939&view=diff
==
--- subversion/trunk/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.c Thu Jul 28 17:51:08 2011
@@ -6033,7 +6033,6 @@ op_delete_txn(void *baton,
   svn_sqlite__stmt_t *stmt;
   apr_int64_t select_depth; /* Depth of what is to be deleted */
   svn_boolean_t refetch_depth = FALSE;
-  svn_boolean_t is_valid_moved_to_relpath = TRUE;
 
   SVN_ERR(svn_sqlite__exec_statements(wcroot->sdb, STMT_CREATE_DELETE_LIST));
 
@@ -6096,9 +6095,6 @@ op_delete_txn(void *baton,
 moved_from_relpath, b->moved_to_relpath));
   SVN_ERR(svn_sqlite__step_done(stmt));
   SVN_ERR(svn_sqlite__reset(stmt));
-
-  /* Make the delete processing below ignore moved-to info. */
-  is_valid_moved_to_relpath = FALSE;
 }
 }
 
@@ -6169,7 +6165,7 @@ op_delete_txn(void *baton,
   /* Delete the node at LOCAL_RELPATH, and possibly mark it as moved. */
   SVN_ERR(svn_sqlite__get_statement(&stmt, wcroot->sdb,
  STMT_INSERT_DELETE_NODE));
-  if (b->moved_to_relpath && is_valid_moved_to_relpath)
+  if (b->moved_to_relpath)
 SVN_ERR(svn_sqlite__bindf(stmt, "isiis",
   wcroot->wc_id, local_relpath,
   select_depth, b->delete_depth,




svn commit: r1151937 - /subversion/branches/revprop-packing/BRANCH-README

2011-07-28 Thread danielsh
Author: danielsh
Date: Thu Jul 28 17:26:27 2011
New Revision: 1151937

URL: http://svn.apache.org/viewvc?rev=1151937&view=rev
Log:
On the revprop-packing branch, add a task to BRANCH-README.

Modified:
subversion/branches/revprop-packing/BRANCH-README

Modified: subversion/branches/revprop-packing/BRANCH-README
URL: 
http://svn.apache.org/viewvc/subversion/branches/revprop-packing/BRANCH-README?rev=1151937&r1=1151936&r2=1151937&view=diff
==
--- subversion/branches/revprop-packing/BRANCH-README (original)
+++ subversion/branches/revprop-packing/BRANCH-README Thu Jul 28 17:26:27 2011
@@ -27,6 +27,8 @@ TODO:
 * add some explicit tests for svnadmin upgrade/pack
   (both revs and revrops)
 
+* assertion failure in svnadmin_tests 13 with pre-1.8-compatible
+
 
 Suggested:
 




svn commit: r1151927 - /subversion/trunk/subversion/libsvn_wc/wc_db.c

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 17:07:16 2011
New Revision: 1151927

URL: http://svn.apache.org/viewvc?rev=1151927&view=rev
Log:
* subversion/libsvn_wc/wc_db.c
  (scan_addition_txn): Rename the confusingly named local variable
   CURRENT_RELPATH, which always contains the relpath of the op_root,
   or is used to compute it, to the more obvious OP_ROOT_RELPATH.
   Also remove a now redundant comment that explained this non-obvious fact.

Modified:
subversion/trunk/subversion/libsvn_wc/wc_db.c

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.c?rev=1151927&r1=1151926&r2=1151927&view=diff
==
--- subversion/trunk/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.c Thu Jul 28 17:07:16 2011
@@ -9116,7 +9116,7 @@ scan_addition_txn(void *baton,
   apr_pool_t *scratch_pool)
 {
   struct scan_addition_baton_t *sab = baton;
-  const char *current_relpath = local_relpath;
+  const char *op_root_relpath = local_relpath;
   const char *build_relpath = "";
 
   /* Initialize most of the OUT parameters. Generally, we'll only be filling
@@ -9181,20 +9181,20 @@ scan_addition_txn(void *baton,
 
 /* Calculate the op root local path components */
 op_depth = svn_sqlite__column_int64(stmt, 0);
-current_relpath = local_relpath;
+op_root_relpath = local_relpath;
 
 for (i = (int)relpath_depth(local_relpath); i > op_depth; --i)
   {
 /* Calculate the path of the operation root */
 repos_prefix_path =
-  svn_relpath_join(svn_relpath_basename(current_relpath, NULL),
+  svn_relpath_join(svn_relpath_basename(op_root_relpath, NULL),
repos_prefix_path,
scratch_pool);
-current_relpath = svn_relpath_dirname(current_relpath, scratch_pool);
+op_root_relpath = svn_relpath_dirname(op_root_relpath, scratch_pool);
   }
 
 if (sab->op_root_relpath)
-  *sab->op_root_relpath = apr_pstrdup(sab->result_pool, current_relpath);
+  *sab->op_root_relpath = apr_pstrdup(sab->result_pool, op_root_relpath);
 
 if (sab->original_repos_relpath
 || sab->original_repos_id
@@ -9202,13 +9202,13 @@ scan_addition_txn(void *baton,
 && *sab->original_revision == SVN_INVALID_REVNUM)
 || sab->status)
   {
-if (local_relpath != current_relpath)
+if (local_relpath != op_root_relpath)
   /* requery to get the add/copy root */
   {
 SVN_ERR(svn_sqlite__reset(stmt));
 
 SVN_ERR(svn_sqlite__bindf(stmt, "is",
-  wcroot->wc_id, current_relpath));
+  wcroot->wc_id, op_root_relpath));
 SVN_ERR(svn_sqlite__step(&have_row, stmt));
 
 if (!have_row)
@@ -9220,7 +9220,7 @@ scan_addition_txn(void *baton,
 return svn_error_createf(SVN_ERR_WC_PATH_NOT_FOUND, NULL,
  _("The node '%s' was not found."),
  path_for_error_message(wcroot,
-
current_relpath,
+
op_root_relpath,
 scratch_pool));
   }
 
@@ -9229,8 +9229,6 @@ scan_addition_txn(void *baton,
   *sab->original_revision = svn_sqlite__column_revnum(stmt, 12);
   }
 
-/* current_relpath / current_abspath
-   as well as the record in stmt contain the data of the op_root */
 if (sab->original_repos_relpath)
   *sab->original_repos_relpath = svn_sqlite__column_text(stmt, 11,
 sab->result_pool);
@@ -9250,7 +9248,7 @@ scan_addition_txn(void *baton,
   SVN_ERR(get_moved_from_info(sab->status,
   sab->moved_from_relpath,
   sab->delete_op_root_relpath,
-  current_relpath, wcroot,
+  op_root_relpath, wcroot,
   local_relpath,
   sab->result_pool,
   scratch_pool));
@@ -9272,13 +9270,13 @@ scan_addition_txn(void *baton,
 
 /* Pointing at op_depth, look at the parent */
 repos_prefix_path =
-  svn_relpath_join(svn_relpath_basename(current_relpath, NULL),
+  svn_relpath_join(svn_relpath_basename(op_root_relpath, NULL),
repos_prefix_path,
scratch_pool);
-current_relpath = svn_relpath_dirna

svn commit: r1151916 - /subversion/trunk/subversion/tests/cmdline/svntest/main.py

2011-07-28 Thread julianfoad
Author: julianfoad
Date: Thu Jul 28 16:37:55 2011
New Revision: 1151916

URL: http://svn.apache.org/viewvc?rev=1151916&view=rev
Log:
Revert r1151672 and r1151680 which made the test suite fail to run all or
many of the Python tests while still reporting success.

The original combined log message of the two revs was effectively:

  Bump the Python tests' equivalent of SVN_VER_MINOR.  Since I'm too
  lazy to make this parse svn_version.h, opt for the least-maintenance
  solution:

  * subversion/tests/cmdline/svntest/main.py
(_create_parser): Make 'server_minor_version' default to inf (positive
  infinity).
(_parse_options): Account for the change.

Modified:
subversion/trunk/subversion/tests/cmdline/svntest/main.py

Modified: subversion/trunk/subversion/tests/cmdline/svntest/main.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/svntest/main.py?rev=1151916&r1=1151915&r2=1151916&view=diff
==
--- subversion/trunk/subversion/tests/cmdline/svntest/main.py (original)
+++ subversion/trunk/subversion/tests/cmdline/svntest/main.py Thu Jul 28 
16:37:55 2011
@@ -1516,7 +1516,7 @@ def _create_parser():
 
   # most of the defaults are None, but some are other values, set them here
   parser.set_defaults(
-server_minor_version=float('+inf'), # positive infinity
+server_minor_version=7,
 url=file_scheme_prefix + pathname2url(os.path.abspath(os.getcwd())),
 http_library=_default_http_library)
 
@@ -1540,8 +1540,7 @@ def _parse_options(arglist=sys.argv[1:])
 
   # If you change the below condition then change
   # ../../../../build/run_tests.py too.
-  if (options.server_minor_version < 3 or options.server_minor_version > 7) \
-  and options.server_minor_version != float('inf'):
+  if options.server_minor_version < 3 or options.server_minor_version > 7:
 parser.error("test harness only supports server minor versions 3-7")
 
   if options.url:




svn commit: r1151914 - /subversion/branches/1.6.x/STATUS

2011-07-28 Thread cmpilato
Author: cmpilato
Date: Thu Jul 28 16:29:10 2011
New Revision: 1151914

URL: http://svn.apache.org/viewvc?rev=1151914&view=rev
Log:
Propose r1151911 for backport.

Modified:
subversion/branches/1.6.x/STATUS

Modified: subversion/branches/1.6.x/STATUS
URL: 
http://svn.apache.org/viewvc/subversion/branches/1.6.x/STATUS?rev=1151914&r1=1151913&r2=1151914&view=diff
==
--- subversion/branches/1.6.x/STATUS (original)
+++ subversion/branches/1.6.x/STATUS Thu Jul 28 16:29:10 2011
@@ -88,6 +88,11 @@ Candidate changes:
Votes:
  +1: pburba, philip
 
+ * r1151911
+   Fix description of svndumpfilter's --targets option.
+   Votes:
+ +1: cmpilato
+
 Veto-blocked changes:
 =
 




svn commit: r1151913 - /subversion/branches/1.7.x/STATUS

2011-07-28 Thread cmpilato
Author: cmpilato
Date: Thu Jul 28 16:28:54 2011
New Revision: 1151913

URL: http://svn.apache.org/viewvc?rev=1151913&view=rev
Log:
Propose r1151911 for backport.

Modified:
subversion/branches/1.7.x/STATUS

Modified: subversion/branches/1.7.x/STATUS
URL: 
http://svn.apache.org/viewvc/subversion/branches/1.7.x/STATUS?rev=1151913&r1=1151912&r2=1151913&view=diff
==
--- subversion/branches/1.7.x/STATUS (original)
+++ subversion/branches/1.7.x/STATUS Thu Jul 28 16:28:54 2011
@@ -185,6 +185,11 @@ Candidate changes:
Votes:
  +0: danielsh
 
+ * r1151911
+   Fix description of svndumpfilter's --targets option.
+   Votes:
+ +1: cmpilato
+
 Veto-blocked changes:
 =
 




svn commit: r1151911 - /subversion/trunk/subversion/svndumpfilter/main.c

2011-07-28 Thread cmpilato
Author: cmpilato
Date: Thu Jul 28 16:27:28 2011
New Revision: 1151911

URL: http://svn.apache.org/viewvc?rev=1151911&view=rev
Log:
* subversion/svndumpfilter/main.c
  (options_table): Fix description of --targets, which is used solely
for reading path prefixes, not as a generic parameter carrier.

Modified:
subversion/trunk/subversion/svndumpfilter/main.c

Modified: subversion/trunk/subversion/svndumpfilter/main.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svndumpfilter/main.c?rev=1151911&r1=1151910&r2=1151911&view=diff
==
--- subversion/trunk/subversion/svndumpfilter/main.c (original)
+++ subversion/trunk/subversion/svndumpfilter/main.c Thu Jul 28 16:27:28 2011
@@ -938,7 +938,8 @@ static const apr_getopt_option_t options
 {"preserve-revprops",  svndumpfilter__preserve_revprops, 0,
  N_("Don't filter revision properties.") },
 {"targets", svndumpfilter__targets, 1,
- N_("Pass contents of file ARG as additional args")},
+ N_("Read additional prefixes, one per line, from\n"
+" file ARG.")},
 {NULL}
   };
 




svn commit: r1151906 - /subversion/trunk/subversion/svn/notify.c

2011-07-28 Thread julianfoad
Author: julianfoad
Date: Thu Jul 28 16:11:17 2011
New Revision: 1151906

URL: http://svn.apache.org/viewvc?rev=1151906&view=rev
Log:
* subversion/svn/notify.c
  (notify): Use separate complete strings so they can be translated.
A follow-up to r102.

Modified:
subversion/trunk/subversion/svn/notify.c

Modified: subversion/trunk/subversion/svn/notify.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/notify.c?rev=1151906&r1=1151905&r2=1151906&view=diff
==
--- subversion/trunk/subversion/svn/notify.c (original)
+++ subversion/trunk/subversion/svn/notify.c Thu Jul 28 16:11:17 2011
@@ -697,9 +697,9 @@ notify(void *baton, const svn_wc_notify_
 case svn_wc_notify_commit_modified:
   /* xgettext: Align the %s's on this and the following 4 messages */
   if ((err = svn_cmdline_printf(pool,
-_("Sending %s   %s\n"),
 nb->is_wc_to_repos_copy
-  ? _("copy of") : "",
+  ? _("Sending copy of   %s\n")
+  : _("Sending%s\n"),
 path_local)))
 goto print_error;
   break;
@@ -709,27 +709,28 @@ notify(void *baton, const svn_wc_notify_
   if (n->mime_type && svn_mime_type_is_binary(n->mime_type))
 {
   if ((err = svn_cmdline_printf(pool,
-_("Adding %s (bin)  %s\n"),
 nb->is_wc_to_repos_copy
-  ? _("copy of") : "",
+  ? _("Adding copy of (bin)  %s\n")
+  : _("Adding  (bin)  %s\n"),
 path_local)))
   goto print_error;
 }
   else
 {
   if ((err = svn_cmdline_printf(pool,
-_("Adding %s%s\n"),
 nb->is_wc_to_repos_copy
-  ? _("copy of") : "",
+  ? _("Adding copy of%s\n")
+  : _("Adding %s\n"),
 path_local)))
 goto print_error;
 }
   break;
 
 case svn_wc_notify_commit_deleted:
-  if ((err = svn_cmdline_printf(pool, _("Deleting %s  %s\n"),
+  if ((err = svn_cmdline_printf(pool,
 nb->is_wc_to_repos_copy
-  ? _("copy of") : "",
+  ? _("Deleting copy of  %s\n")
+  : _("Deleting   %s\n"),
 path_local)))
 goto print_error;
   break;
@@ -737,9 +738,9 @@ notify(void *baton, const svn_wc_notify_
 case svn_wc_notify_commit_replaced:
 case svn_wc_notify_commit_copied_replaced:
   if ((err = svn_cmdline_printf(pool,
-_("Replacing %s %s\n"),
 nb->is_wc_to_repos_copy
-  ? _("copy of") : "",
+  ? _("Replacing copy of %s\n")
+  : _("Replacing  %s\n"),
 path_local)))
 goto print_error;
   break;




svn commit: r1151904 - /subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c

2011-07-28 Thread hwright
Author: hwright
Date: Thu Jul 28 16:03:53 2011
New Revision: 1151904

URL: http://svn.apache.org/viewvc?rev=1151904&view=rev
Log:
Remove a redundant call to svn_uuid_generate().

* subversion/libsvn_fs_fs/fs_fs.c
  (svn_fs_fs__create): Call svn_fs_fs__set_uuid() with a NULL uuid.  The
function is already set up to generate one for us if we don't provide
one, so let's just use that functionality.

Modified:
subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c

Modified: subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c?rev=1151904&r1=1151903&r2=1151904&view=diff
==
--- subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c (original)
+++ subversion/trunk/subversion/libsvn_fs_fs/fs_fs.c Thu Jul 28 16:03:53 2011
@@ -6631,7 +6631,7 @@ svn_fs_fs__create(svn_fs_t *fs,
   ? "0\n" : "0 1 1\n"),
  pool));
   SVN_ERR(svn_io_file_create(path_lock(fs, pool), "", pool));
-  SVN_ERR(svn_fs_fs__set_uuid(fs, svn_uuid_generate(pool), pool));
+  SVN_ERR(svn_fs_fs__set_uuid(fs, NULL, pool));
 
   SVN_ERR(write_revision_zero(fs));
 




svn propchange: r1151686 - svn:log

2011-07-28 Thread julianfoad
Author: julianfoad
Revision: 1151686
Modified property: svn:log

Modified: svn:log at Thu Jul 28 16:01:36 2011
--
--- svn:log (original)
+++ svn:log Thu Jul 28 16:01:36 2011
@@ -1,2 +1,2 @@
-On the revprop-packing branch, merge r1151672 and r1151680 from trunk, 
-dquote> using a 1.7.0-beta1 client.
+On the revprop-packing branch, merge r1151672 and r1151680 from trunk,
+using a 1.7.0-beta1 client.



svn propchange: r1151662 - svn:log

2011-07-28 Thread julianfoad
Author: julianfoad
Revision: 1151662
Modified property: svn:log

Modified: svn:log at Thu Jul 28 15:56:04 2011
--
--- svn:log (original)
+++ svn:log Thu Jul 28 15:56:04 2011
@@ -1,5 +1,5 @@
 On the revprop-packing branch, split out a helper function.
 
 * subversion/libsvn_fs_fs/fs_fs.c
-  (path_revprops_shard): New.
+  (path_revprops_pack): New.
   (revision_proplist): Use new helper, eliminating three local variables.



svn commit: r1151873 - /subversion/trunk/build/run_tests.py

2011-07-28 Thread rhuijben
Author: rhuijben
Date: Thu Jul 28 14:34:35 2011
New Revision: 1151873

URL: http://svn.apache.org/viewvc?rev=1151873&view=rev
Log:
* build/run_tests.py
  (_run_c_test): Remove carriage return from c test stdout on Windows to reduce
the amount of unneeded vertical whitespace in the log output.

Modified:
subversion/trunk/build/run_tests.py

Modified: subversion/trunk/build/run_tests.py
URL: 
http://svn.apache.org/viewvc/subversion/trunk/build/run_tests.py?rev=1151873&r1=1151872&r2=1151873&view=diff
==
--- subversion/trunk/build/run_tests.py (original)
+++ subversion/trunk/build/run_tests.py Thu Jul 28 14:34:35 2011
@@ -345,6 +345,10 @@ class TestHarness:
 stderr=self.log)
 line = prog.stdout.readline()
 while line:
+  if sys.platform == 'win32':
+# Remove CRs inserted because we parse the output as binary.
+line = line.replace('\r', '')
+
   # If using --log-to-stdout self.log in None.
   if self.log:
 self.log.write(line)




svn commit: r1151854 - /subversion/trunk/INSTALL

2011-07-28 Thread julianfoad
Author: julianfoad
Date: Thu Jul 28 14:05:53 2011
New Revision: 1151854

URL: http://svn.apache.org/viewvc?rev=1151854&view=rev
Log:
* INSTALL
  Fix a broken link and an outdated comment.

Modified:
subversion/trunk/INSTALL

Modified: subversion/trunk/INSTALL
URL: 
http://svn.apache.org/viewvc/subversion/trunk/INSTALL?rev=1151854&r1=1151853&r2=1151854&view=diff
==
--- subversion/trunk/INSTALL (original)
+++ subversion/trunk/INSTALL Thu Jul 28 14:05:53 2011
@@ -505,7 +505,7 @@ I.INTRODUCTION
   with the C compiler. If you're using MSVC 6, and don't have MASM 6,
   a free MASM-compatible assembler is available here:
 
-  http://www.masm32.org/
+  http://www.masm32.com/
 
   You only need ML.EXE and ML.ERR from this distribution.
 
@@ -758,7 +758,7 @@ II.   INSTALLATION
 
   $ svn co https://svn.apache.org/repos/asf/subversion/trunk svn
   $ cd svn
-  $ # get neon/apr as required
+  $ # get any dependencies to be built in-tree, if required
   $ chmod +x autogen.sh
   $ ./autogen.sh
   $ mkdir ../obj




svn commit: r1151824 - in /subversion/trunk/subversion/libsvn_wc: wc-queries.sql wc_db.c

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 12:48:58 2011
New Revision: 1151824

URL: http://svn.apache.org/viewvc?rev=1151824&view=rev
Log:
Record correct moved-from information for nodes which are moved multiple times.

The sequence "svn mv A B; svn mv B C;" ended up incorrectly recording
"C moved-from B". It must record "C moved-from A" instead.

* subversion/libsvn_wc/wc-queries.sql
  (STMT_UPDATE_MOVED_TO_RELPATH): New. Updates the moved-to relpath on the
   delete-half of a move. (Note that we update the moved-to column to get
   valid moved-from queries because, in the current implementation,
   moved-from information is inferred by a query on moved-to columns
   and is not actually stored in the DB.)

* subversion/libsvn_wc/wc_db.c
  (op_delete_txn): If the delete is the delete-half of a move, and the
   node being deleted was previously moved-here, fix up the moved-to
   relpath recorded on the delete-half of the original move.

Modified:
subversion/trunk/subversion/libsvn_wc/wc-queries.sql
subversion/trunk/subversion/libsvn_wc/wc_db.c

Modified: subversion/trunk/subversion/libsvn_wc/wc-queries.sql
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc-queries.sql?rev=1151824&r1=1151823&r2=1151824&view=diff
==
--- subversion/trunk/subversion/libsvn_wc/wc-queries.sql (original)
+++ subversion/trunk/subversion/libsvn_wc/wc-queries.sql Thu Jul 28 12:48:58 
2011
@@ -1335,6 +1335,13 @@ WHERE wc_id = ?1
 SELECT local_relpath FROM nodes_current
 WHERE wc_id = ?1 AND moved_to = ?2
 
+-- STMT_UPDATE_MOVED_TO_RELPATH
+UPDATE NODES SET moved_to = ?3
+WHERE wc_id = ?1 AND local_relpath = ?2
+  AND op_depth =
+   (SELECT MAX(op_depth) FROM nodes
+WHERE wc_id = ?1 AND local_relpath = ?2 AND op_depth > 0)
+
 /* - */
 
 /* Queries for verification. */

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.c?rev=1151824&r1=1151823&r2=1151824&view=diff
==
--- subversion/trunk/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.c Thu Jul 28 12:48:58 2011
@@ -6033,6 +6033,7 @@ op_delete_txn(void *baton,
   svn_sqlite__stmt_t *stmt;
   apr_int64_t select_depth; /* Depth of what is to be deleted */
   svn_boolean_t refetch_depth = FALSE;
+  svn_boolean_t is_valid_moved_to_relpath = TRUE;
 
   SVN_ERR(svn_sqlite__exec_statements(wcroot->sdb, STMT_CREATE_DELETE_LIST));
 
@@ -6067,6 +6068,40 @@ op_delete_txn(void *baton,
 }
   SVN_ERR(svn_sqlite__reset(stmt));
 
+  if (b->moved_to_relpath)
+{
+  const char *moved_from_relpath;
+  const char *delete_op_root_relpath;
+
+  /* ### call scan_addition_txn() directly? */
+  if (status == svn_wc__db_status_added)
+SVN_ERR(scan_addition(&status, NULL, NULL, NULL,
+  NULL, NULL, NULL,
+  &moved_from_relpath,
+  &delete_op_root_relpath,
+  wcroot, local_relpath,
+  scratch_pool, scratch_pool));
+
+  if (status == svn_wc__db_status_moved_here &&
+  strcmp(moved_from_relpath, delete_op_root_relpath) == 0)
+{
+  /* The node has already been moved and is being moved again.
+   * Update the existing moved_to path at the delete-half of
+   * the prior move. The source of a move is in the BASE tree
+   * so it remains constant if a node is moved around multiple
+   * times. */
+  SVN_ERR(svn_sqlite__get_statement(&stmt, wcroot->sdb,
+STMT_UPDATE_MOVED_TO_RELPATH));
+  SVN_ERR(svn_sqlite__bindf(stmt, "iss", wcroot->wc_id,
+moved_from_relpath, b->moved_to_relpath));
+  SVN_ERR(svn_sqlite__step_done(stmt));
+  SVN_ERR(svn_sqlite__reset(stmt));
+
+  /* Make the delete processing below ignore moved-to info. */
+  is_valid_moved_to_relpath = FALSE;
+}
+}
+
   if (op_root)
 {
   svn_boolean_t below_base;
@@ -6134,7 +6169,7 @@ op_delete_txn(void *baton,
   /* Delete the node at LOCAL_RELPATH, and possibly mark it as moved. */
   SVN_ERR(svn_sqlite__get_statement(&stmt, wcroot->sdb,
  STMT_INSERT_DELETE_NODE));
-  if (b->moved_to_relpath)
+  if (b->moved_to_relpath && is_valid_moved_to_relpath)
 SVN_ERR(svn_sqlite__bindf(stmt, "isiis",
   wcroot->wc_id, local_relpath,
   select_depth, b->delete_depth,




svn commit: r1151780 - /subversion/trunk/subversion/libsvn_wc/wc_db.c

2011-07-28 Thread stsp
Author: stsp
Date: Thu Jul 28 10:11:43 2011
New Revision: 1151780

URL: http://svn.apache.org/viewvc?rev=1151780&view=rev
Log:
Make the wc_db internal scan_addition() function return moved-from
information as relative paths, rather than absolute paths. This makes
it easier for other internal functions in wc_db to use moved-from
information provided by scan_addition().

* subversion/libsvn_wc/wc_db.c
  (scan_addition, get_moved_from_info, scan_addition_baton_t): Rename
   MOVED_FROM_ABSPATH and DELETE_OP_ROOT_ABSPATH to MOVED_FROM_RELPATH
   and DELETE_OP_ROOT_RELPATH.
  (scan_addition_txn): Track rename of fields in scan_addition baton.
  (svn_wc__db_scan_addition): Convert moved-from information returned
   by scan_addition() from relative to absolute paths.

Modified:
subversion/trunk/subversion/libsvn_wc/wc_db.c

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.c?rev=1151780&r1=1151779&r2=1151780&view=diff
==
--- subversion/trunk/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.c Thu Jul 28 10:11:43 2011
@@ -366,8 +366,8 @@ scan_addition(svn_wc__db_status_t *statu
   const char **original_repos_relpath,
   apr_int64_t *original_repos_id,
   svn_revnum_t *original_revision,
-  const char **moved_from_abspath,
-  const char **delete_op_root_abspath,
+  const char **moved_from_relpath,
+  const char **delete_op_root_relpath,
   svn_wc__db_wcroot_t *wcroot,
   const char *local_relpath,
   apr_pool_t *result_pool,
@@ -8965,18 +8965,18 @@ svn_wc__db_scan_base_repos(const char **
  * Compute moved-from information for the node at LOCAL_RELPATH which
  * has been determined as having been moved-here.
  * Return an appropriate status in *STATUS (usually "moved-here").
  * If MOVED_FROM_ABSPATH is not NULL, set *MOVED_FROM_ABSPATH to the
  * absolute path of the move-source node in *MOVED_FROM_ABSPATH.
  * If DELETE_OP_ROOT_ABSPATH is not NULL, set *DELETE_OP_ROOT_ABSPATH
  * to the absolute path of the op-root of the delete-half of the move.
  * If moved-from information cannot be derived, set both *MOVED_FROM_ABSPATH
  * and *DELETE_OP_ROOT_ABSPATH to NULL, and return a "copied" status.
  * COPY_OPT_ROOT_RELPATH is the relpath of the op-root of the copied-half
  * of the move. */
 static svn_error_t *
 get_moved_from_info(svn_wc__db_status_t *status,
-const char **moved_from_abspath,
-const char **delete_op_root_abspath,
+const char **moved_from_relpath,
+const char **delete_op_root_relpath,
 const char *copy_op_root_relpath,
 svn_wc__db_wcroot_t *wcroot,
 const char *local_relpath,
@@ -8998,10 +8998,10 @@ get_moved_from_info(svn_wc__db_status_t 
* the move operation was interrupted mid-way between the copy
* and the delete. Treat this node as a normal copy. */
   *status = svn_wc__db_status_copied;
-  if (moved_from_abspath)
-*moved_from_abspath = NULL;
-  if (delete_op_root_abspath)
-*delete_op_root_abspath = NULL;
+  if (moved_from_relpath)
+*moved_from_relpath = NULL;
+  if (delete_op_root_relpath)
+*delete_op_root_relpath = NULL;
 
   SVN_ERR(svn_sqlite__reset(stmt));
   return SVN_NO_ERROR;
@@ -9010,30 +9010,25 @@ get_moved_from_info(svn_wc__db_status_t 
   /* It's a properly recorded move. */
   *status = svn_wc__db_status_moved_here;
 
-  if (moved_from_abspath || delete_op_root_abspath)
+  if (moved_from_relpath || delete_op_root_relpath)
 {
-  const char *delete_op_root_relpath;
+  const char *db_delete_op_root_relpath;
 
   /* The moved-from path from the DB is the relpath of
* the op_root of the delete-half of the move. */
-  delete_op_root_relpath = svn_sqlite__column_text(stmt, 0, scratch_pool);
-
-  /* Return the abspath of the op_root of the delete-half. */
-  if (delete_op_root_abspath)
-*delete_op_root_abspath = svn_dirent_join(wcroot->abspath,
-  delete_op_root_relpath,
-  result_pool);
+  db_delete_op_root_relpath = svn_sqlite__column_text(stmt, 0,
+  result_poo
@@ -8965,18 +8965,18 @@ svn_wc__db_scan_base_repos(const char **
  * has been determined as having been moved-here.
  * Return an appropriate status in *STATUS (usually "moved-here").
- * If MOVED_FROM_ABSPATH is not NULL, set *MOVED_FROM_ABSPATH to the
- * absolute path of the move-source node in *MOVED_FROM_ABSPATH.
- * If DELETE_OP_ROOT_ABSPATH is not NULL, set *DELETE_OP_ROOT_ABSPATH
- * to the absolute path of the op-root of the delete-half of the move.
- * If moved-from information cannot be derived, set both *MOVED_FROM_ABSPATH
- * and *DELETE_OP_ROOT_ABSPATH to NULL, and return a "copied" status.
+ * If MOVED_FROM_RELPATH is not NULL, set *MOVED_FROM_RELPATH to the
+ * path of the move-source node in *MOVED_FROM_RELPATH.
+ * If DELETE_OP_ROOT_RELPATH is not NULL, set *DELETE_OP_ROOT_RELPATH
+ * to the path of the op-root of the delete-half of the move.
+ * If moved-from information cannot be derived, set both *MOVED_FROM_RELPATH
+ * and *DELETE_OP_ROOT_RELPATH to NULL, and return a "copied" status.
  * COPY_OPT_ROOT_RELPATH is the relpath of the op-root of the copied-half
  * of the move. */